LPARAMETERS tcFRXFullFileName, tnOutPutFileType

*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus

*-- DO UsingReportListener WITH 'C:\MyReports\Customer list.FRX', 2

*-- tcFRXFullFileName	: FRX File Path + FileName
*-- tnOutPutFileType	: cnHTML, cnRTF, cnEXCEL, cnPDF, cnIMAGE, cnPREVIEW


***************************************************************************************************************************
*-- Export file types
***************************************************************************************************************************
#DEFINE cnWORD 					         		1
#DEFINE cnHTML               			 			2
#DEFINE cnRTF               			 			3
#DEFINE cnEXCEL               			 		4
#DEFINE cnPREVIEW               			 		6
#DEFINE cnPDF	               			 	   7
#DEFINE cnIMAGE	               			 	8

***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         		1
#DEFINE cnOUTPUT_PRINT			         		2
#DEFINE cnOUTPUT_EMAIL			         		3
#DEFINE cnOUTPUT_FILE		 	         		4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP       1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG			2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF			3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF			4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG			5

***************************************************************************************************************************
*-- Excel output file formats
***************************************************************************************************************************
#DEFINE cnEXCEL_OUTPUT_FULL_PLAIN				3
#DEFINE cnEXCEL_OUTPUT_A_LA_TABLE_XLSX			8
#DEFINE cnEXCEL_OUTPUT_RAW_DATA_XLSX			9
#DEFINE cnEXCEL_OUTPUT_BRUTAL_XLSX				10

***************************************************************************************************************************
*-- RTF output file formats
***************************************************************************************************************************
#DEFINE cnRTF_OUTPUT_OBJECT						1
#DEFINE cnRTF_OUTPUT_PLAIN							2

LOCAL loListener

LOCAL lcReportFullName
LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath
LOCAL lcRunProgram
LOCAL lcFRX2AnyLibrary

LOCAL lnOutPutFileType

lcRunProgram = SYS(16,0)

CD LEFT(lcRunProgram, RAT('\', lcRunProgram))

lcReportFullName = IIF(EMPTY(tcFRXFullFileName), FULLPATH('..\..\Reports\Invoice.FRX'), tcFRXFullFileName)


lnOutPutFileType = IIF(VARTYPE(tnOutPutFileType) = 'N' AND ;
	INLIST(tnOutPutFileType, cnWORD, cnHTML, cnRTF, cnEXCEL, cnPDF, cnIMAGE, cnPREVIEW), tnOutPutFileType, cnPDF)

IF !FILE(lcReportFullName)
	=MESSAGEBOX('File ' + lcReportFullName + ' does not exist.', 16, 'Error')
ELSE

*-- Get a reference to the Listener class from the Listener.vcx
	loListener = NEWOBJECT("Listener", "..\ReportListener\VCX\Listener.VCX")	
	
	IF TYPE('loListener') = 'O'
*-- Turn off UI feedback and user prompts at end of run
		loListener.QUIETMODE = .T.

		lcOutPutFileName = JUSTSTEM(lcReportFullName)
		lcOutPutFilePath = JUSTPATH(lcRunProgram) + "\OutPut\"

		SET PATH TO  ..\..\..\

		lcFRX2AnyLibrary = 'FRX2Any'	 
		SET CLASSLIB TO &lcFRX2AnyLibrary IN FRX2Any.APP ALIAS FRX2Any				
		
	
		DO CASE
			CASE lnOutPutFileType = cnRTF
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.RTFFile')

			CASE lnOutPutFileType = cnWORD
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.WORDFile')

			CASE lnOutPutFileType = cnHTML
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.HTMLFile')

			CASE lnOutPutFileType = cnEXCEL
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.ExcelFile')

			CASE lnOutPutFileType = cnPDF
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.PDFFile')

			CASE lnOutPutFileType = cnIMAGE
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.ImageFile')

			CASE lnOutPutFileType = cnPREVIEW
				loListener.oFRX2Any = CREATEOBJECT('FRX2Any.PreviewFile')

		ENDCASE


		IF TYPE('loListener.oFRX2Any') = 'O'
*-- Unlock FRX2Any
			loListener.oFRX2Any.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loListener.oFRX2Any.cExportFileName should not include file extension. For example: loListener.oFRX2Any.cExportFileName = "ReportOutput"
			loListener.oFRX2Any.cExportFileName = lcOutPutFileName

*-- NOTE: loListener.oFRX2Any.cSaveFolder should contain only path to the output file. For example: loListener.oFRX2Any.cSaveFolder = "c:\MyApp\MyOutPut\"
			loListener.oFRX2Any.cSaveFolder = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
			loListener.oFRX2Any.nOutPutType = cnOUTPUT_SCREEN
			
			DO CASE
				CASE lnOutPutFileType = cnHTML
*-- Embed Images to HTML file
					loListener.oFRX2Any.lEmbedImage = .T.

				CASE lnOutPutFileType = cnEXCEL
					loListener.oFRX2Any.nExcelOutPutType = cnEXCEL_OUTPUT_BRUTAL_XLSX
					loListener.oFRX2Any.lPrintEmptyField = .T.

				CASE lnOutPutFileType = cnIMAGE
*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
					loListener.oFRX2Any.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_TIF
					
				CASE lnOutPutFileType = cnRTF
					loListener.oFRX2Any.nRTFOutPutType = cnRTF_OUTPUT_PLAIN

			ENDCASE

			REPORT FORM (lcReportFullName) OBJECT loListener NOWAIT
			

			IF lnOutPutFileType = cnPREVIEW 
				DO CASE
				CASE loListener.oFRX2Any.nOutPutType = cnOUTPUT_SCREEN			
					loListener.oFRX2Any.PreviewReport()				
					
				CASE loListener.oFRX2Any.nOutPutType = cnOUTPUT_PRINT
					loListener.oFRX2Any.PrintReport()				

				ENDCASE	
				
				loListener.oFRX2Any = .NULL.
				
			ENDIF
			
		ENDIF

	ENDIF

ENDIF


